==> haskell-interpolate-0.2.0-59-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-DGoYl4gCnVdHzoMq0NBhFo
key: interpolate-0.2.0-DGoYl4gCnVdHzoMq0NBhFo
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: a62358e5cbeaa3dc2f4ad263b354dc54
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.6.3/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-DGoYl4gCnVdHzoMq0NBhFo
depends:
    base-4.12.0.0 haskell-src-meta-0.8.0.3-56x4OHOUXM55SJyiQWw8MD
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.0-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-J5t97NuBTZh2v7COIXa91U
key: interpolate-0.2.0-J5t97NuBTZh2v7COIXa91U
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: 040308426ed47c553f3efde92fc4751e
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.6.3/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-J5t97NuBTZh2v7COIXa91U
depends:
    base-4.12.0.0 haskell-src-meta-0.8.0.3-4wszG05U4K8AvYSAywB7K6
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
